@@ -35,11 +35,16 @@ def click_detector(html_content, key=None):
 if not _RELEASE:
     import streamlit as st
 
-    content1 = """<p><a href='#' id='Link 1'>First link</a></p>
+    content = """<p><a href='#' id='Link 1'>First link</a></p>
         <p><a href='#' id='Link 2'>Second link</a></p>
         <a href='#' id='Image 1'><img width='20%' src='https://images.unsplash.com/photo-1565130838609-c3a86655db61?w=200'></a>
         <a href='#' id='Image 2'><img width='20%' src='https://images.unsplash.com/photo-1565372195458-9de0b320ef04?w=200'></a>
         """
-    clicked = click_detector(content1)
+    clicked = click_detector(content)
 
-    st.markdown(f"**{clicked} clicked**" if clicked != "" else "**No click**")
+    st.markdown(
+        f"<p><b>{clicked} clicked</b></p>"
+        if clicked != ""
+        else "<p><b>No click</b></p>",
+        unsafe_allow_html=True,
+    )
